package com.fireworksdk.bridge.components.videofeed

import android.content.Context
import android.util.AttributeSet
import android.view.ViewGroup
import android.widget.FrameLayout
import com.firework.error.FwErrorListener
import com.firework.videofeed.FeedViewStateListener
import com.firework.videofeed.FwVideoFeedView
import com.fireworksdk.bridge.models.*
import com.fireworksdk.bridge.utils.FWConfigUtil
import com.fireworksdk.bridge.utils.FWLanguageUtil


class FWVideoFeed(
  context: Context,
  attrs: AttributeSet?
) : FrameLayout(context, attrs) {

  constructor(context: Context) : this(context, null)

  val videoFeedView = FwVideoFeedView(context)
  var videoFeedPropsModel: FWVideoFeedPropsModel = FWVideoFeedPropsModel()
  private var isInit = false

  private var onWindowFocusChanged = false
  private var feedViewStateListener: FeedViewStateListener? = null

  init {
    FWLanguageUtil.getInstance(context).updateBaseContextLocale(context)
    videoFeedView.layoutDirection = LAYOUT_DIRECTION_LOCALE
    addView(videoFeedView, LayoutParams(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.MATCH_PARENT))
  }

  fun setVideoFeedLayoutParams(l: LayoutParams?) {
    l ?: return
    videoFeedView.layoutParams = l
    requestLayout()
  }

  fun initVideoFeedView() {
    if (isInit) {
      return
    }
    val viewOptionsBuilder = FWConfigUtil.generateViewOptionsBuilder(context, videoFeedPropsModel)
    videoFeedView.init(viewOptionsBuilder.build())
    isInit = true
  }

  fun refresh() {
    videoFeedView.refresh()
  }

  fun getFeedId(): String {
    return videoFeedView.feedId
  }

  fun setOnFeedViewStateListener(feedViewStateListener: FeedViewStateListener?) {
    this.feedViewStateListener = feedViewStateListener
    videoFeedView.setOnFeedViewStateListener { feedViewState ->
      if (!onWindowFocusChanged) {
        videoFeedView.dispatchWindowFocusChanged(true)
        onWindowFocusChanged = true
      }

      feedViewStateListener?.onLoadStateChanged(
        feedViewState
      )
    }
  }

  fun setOnErrorListener(errorListener: FwErrorListener?) {
    videoFeedView.setOnErrorListener { error ->
      if (!onWindowFocusChanged) {
        videoFeedView.dispatchWindowFocusChanged(true)
        onWindowFocusChanged = true
      }

      errorListener?.onFwError(error)
    }
  }

}
