package com.fireworksdk.bridge.flutter

import android.content.Context
import androidx.annotation.NonNull
import androidx.fragment.app.FragmentActivity
import com.fireworksdk.bridge.flutter.handler.*
import com.fireworksdk.bridge.flutter.models.FWChannelName
import com.fireworksdk.bridge.flutter.models.FWViewTypeId
import com.fireworksdk.bridge.flutter.platformviewfactory.FWLoadingFactory
import com.fireworksdk.bridge.flutter.platformviewfactory.FWStoryBlockFactory
import com.fireworksdk.bridge.flutter.platformviewfactory.FWVideoFeedFactory
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.embedding.engine.plugins.FlutterPlugin.FlutterPluginBinding
import io.flutter.embedding.engine.plugins.activity.ActivityAware
import io.flutter.embedding.engine.plugins.activity.ActivityPluginBinding
import io.flutter.plugin.common.BinaryMessenger
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.platform.PlatformViewRegistry


/** FireworkFlutterSdkPlugin */
class FireworkFlutterSdkPlugin : FlutterPlugin, ActivityAware {
  private var fwSdkModuleChannel: MethodChannel? = null
  private var fwShoppingModuleChannel: MethodChannel? = null
  private var fwLiveStreamModuleChannel: MethodChannel? = null
  private var fwNavigatorModuleChannel: MethodChannel? = null

  private lateinit var context: Context
  private lateinit var binaryMessenger: BinaryMessenger
  private lateinit var platformViewRegistry: PlatformViewRegistry

  /**
   * your plugin is now attached to a Flutter experience.
   */
  override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPluginBinding) {
    context = flutterPluginBinding.applicationContext
    binaryMessenger = flutterPluginBinding.binaryMessenger
    platformViewRegistry = flutterPluginBinding.platformViewRegistry

    // FireworkSdkModule
    fwSdkModuleChannel = MethodChannel(binaryMessenger, FWChannelName.FireworkSdkModule.rawValue)
    fwSdkModuleChannel?.setMethodCallHandler(
      FWSdkModuleHandler(context, fwSdkModuleChannel)
    )

    // FireworkShoppingModule
    fwShoppingModuleChannel =
      MethodChannel(binaryMessenger, FWChannelName.FireworkShoppingModule.rawValue)
    fwShoppingModuleChannel?.setMethodCallHandler(
      FWShoppingModuleHandler(
        context,
        fwShoppingModuleChannel
      )
    )

    // livestream module
    fwLiveStreamModuleChannel =
      MethodChannel(binaryMessenger, FWChannelName.FireworkLiveStreamModule.rawValue)
    fwLiveStreamModuleChannel?.setMethodCallHandler(
      FWLiveStreamModuleHandler(
        fwLiveStreamModuleChannel
      )
    )

    // fwNavigatorModule
    fwNavigatorModuleChannel = MethodChannel(binaryMessenger, FWChannelName.FireworkNavigatorModule.rawValue)
    fwNavigatorModuleChannel?.setMethodCallHandler(
      FWNavigatorModuleHandler()
    )
  }

  /**
   * your plugin is no longer attached to a Flutter experience.
   */
  override fun onDetachedFromEngine(@NonNull binding: FlutterPluginBinding) {
    fwSdkModuleChannel?.setMethodCallHandler(null)
    fwSdkModuleChannel = null

    fwShoppingModuleChannel?.setMethodCallHandler(null)
    fwShoppingModuleChannel = null

    fwLiveStreamModuleChannel?.setMethodCallHandler(null)
    fwLiveStreamModuleChannel = null

    fwNavigatorModuleChannel?.setMethodCallHandler(null)
    fwNavigatorModuleChannel = null
  }

  /**
   * your plugin is now attached to an Activity
   */
  override fun onAttachedToActivity(binding: ActivityPluginBinding) {
    val activity = binding.activity
    if (activity is FragmentActivity) {
      platformViewRegistry.registerViewFactory(
        FWViewTypeId.FireworkVideoFeed.rawValue,
        FWVideoFeedFactory(binding.activity, binaryMessenger, fwSdkModuleChannel)
      )
      platformViewRegistry.registerViewFactory(
        FWViewTypeId.FireworkStoryBlock.rawValue,
        FWStoryBlockFactory(binding.activity as FragmentActivity, binaryMessenger)
      )
      platformViewRegistry.registerViewFactory(
        FWViewTypeId.FireworkLoading.rawValue,
        FWLoadingFactory(binding.activity as FragmentActivity)
      )
    } else {
      throw ClassCastException("Please change your Activity to FlutterFragmentActivity ")
    }

  }

  /**
   *  the Activity your plugin was attached to was destroyed to change configuration.
   *  This call will be followed by onReattachedToActivityForConfigChanges().
   */
  override fun onDetachedFromActivityForConfigChanges() {
  }

  /**
   *  your plugin is now attached to a new Activity after a configuration change.
   */
  override fun onReattachedToActivityForConfigChanges(binding: ActivityPluginBinding) {
  }

  /**
   *  your plugin is no longer associated with an Activity. Clean up references.
   */
  override fun onDetachedFromActivity() {
  }

}
