package com.fireworksdk.bridge.flutter.handler

import androidx.annotation.Keep
import com.firework.analyticsevents.livestream.LivestreamAnalyticEvent
import com.firework.bus.FwAnalyticCallable
import com.firework.sdk.FireworkSdk
import com.fireworksdk.bridge.flutter.models.FWLiveStreamModuleCallMethod
import com.fireworksdk.bridge.flutter.utils.FWEventUtils
import com.fireworksdk.bridge.models.FWLiveStreamEventDetailsModel
import com.fireworksdk.bridge.models.enums.FWLiveStreamEventName
import com.fireworksdk.bridge.models.FWLiveStreamMessageDetailsModel
import com.fireworksdk.bridge.models.weakProperty
import com.fireworksdk.bridge.utils.FWLogUtils
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel

class FWLiveStreamModuleHandler(
  channel: MethodChannel?
) : MethodChannel.MethodCallHandler {

  private val methodChannel by weakProperty<MethodChannel?>(channel)

  override fun onMethodCall(call: MethodCall, result: MethodChannel.Result) {
    when (call.method) {
      FWLiveStreamModuleCallMethod.Init.rawValue -> {
        FireworkSdk.analytics.register(this)
        result.success(null)
      }

      else -> {
        result.notImplemented()
      }
    }
  }

  @Keep
  @FwAnalyticCallable
  fun onLivestreamEvent(event: LivestreamAnalyticEvent) {
    when (event) {
      is LivestreamAnalyticEvent.UserSentChatMessage -> {
        FWLogUtils.d { "userSentChat: $event" }
        FWEventUtils.sendLiveStreamChatEvent(
          methodChannel,
          FWLiveStreamEventName.UserSendChat.rawValue,
          FWLiveStreamMessageDetailsModel(event.messageId, event.username, event.messageText),
          FWLiveStreamEventDetailsModel(event.livestreamId)
        )
      }
      is LivestreamAnalyticEvent.UserJoined -> {
        FWLogUtils.d { "userJoined: $event" }
        FWEventUtils.sendLiveStreamEvent(
          methodChannel,
          FWLiveStreamEventName.UserJoin.rawValue,
          FWLiveStreamEventDetailsModel(event.livestreamId)
        )
      }
      is LivestreamAnalyticEvent.UserLeft -> {
        FWLogUtils.d { "userLeft: $event" }
        FWEventUtils.sendLiveStreamEvent(
          methodChannel,
          FWLiveStreamEventName.UserLeave.rawValue,
          FWLiveStreamEventDetailsModel(event.livestreamId)
        )
      }
      is LivestreamAnalyticEvent.UserSentLike -> {
        FWLogUtils.d { "userSentLike: $event" }
        FWEventUtils.sendLiveStreamEvent(
          methodChannel,
          FWLiveStreamEventName.UserSendLike.rawValue,
          FWLiveStreamEventDetailsModel(event.livestreamId)
        )
      }
    }
  }


}