package com.fireworksdk.bridge.models

import org.json.JSONObject

object FWTrackPurchaseModelDeserializer {

  private const val ORDER_ID_KEY = "orderId"
  private const val VALUE_KEY = "value"
  private const val CURRENCY_CODE_KEY = "currencyCode"
  private const val COUNTRY_KEY = "countryCode"
  private const val ADDITIONAL_INFO_KEY = "additionalInfo"


  fun deserialize(responseJson: JSONObject?): FWTrackPurchaseModel? {
    responseJson ?: return null
    val productId = if (responseJson.has(ORDER_ID_KEY)) responseJson.optString(ORDER_ID_KEY) else null
    val value = if (responseJson.has(VALUE_KEY)) responseJson.optDouble(VALUE_KEY) else null
    val currencyCode = if (responseJson.has(CURRENCY_CODE_KEY)) responseJson.optString(CURRENCY_CODE_KEY) else null
    val countryCode = if (responseJson.has(COUNTRY_KEY)) responseJson.optString(COUNTRY_KEY) else null
    val additionalInfoObject = if (responseJson.has(ADDITIONAL_INFO_KEY)) responseJson.optJSONObject(ADDITIONAL_INFO_KEY) else null

    var additionalInfo: Map<String, String>? = null

    val keys = additionalInfoObject?.keys()
    if (keys != null) {
      val additionalInfoMutableMap: MutableMap<String, String> = mutableMapOf()
      for (key in keys) {
        val v = if (additionalInfoObject.has(key)) additionalInfoObject.optString(key) else null
        if (v != null) {
          additionalInfoMutableMap[key] = v
        }
      }
      additionalInfo = additionalInfoMutableMap.toMap()
    }

    return FWTrackPurchaseModel(
      orderId = productId,
      value = value,
      currencyCode = currencyCode,
      countryCode = countryCode,
      additionalInfo = additionalInfo,
    )
  }

}