package com.fireworksdk.bridge.models

import org.json.JSONArray
import org.json.JSONObject

object FWVideoShoppingProductDeserializer {

  private const val PRODUCT_ID_KEY = "productId"
  private const val NAME_KEY = "name"
  private const val DESCRIPTION_KEY = "description"
  private const val UNITS_KEY = "units"
  private const val IS_AVAILABLE_KEY = "isAvailable"

  private const val UNIT_ID_KEY = "unitId"
  private const val PRICE_KEY = "price"
  private const val URL_KEY = "url"
  private const val IMAGE_URL_KEY = "imageUrl"
  private const val OPTIONS_KEY = "options"

  private const val AMOUNT_KEY = "amount"
  private const val CURRENCY_CODE_KEY = "currencyCode"

  private const val VALUE_KEY = "value"

  fun deserializeArray(responseJsonArray: JSONArray?): List<FWVideoShoppingProduct>? {
    responseJsonArray ?: return null
    val list = mutableListOf<FWVideoShoppingProduct>()
    (0 until responseJsonArray.length()).forEach {
      val value = responseJsonArray.getJSONObject(it)
      val item = deserialize(value)
      list.add(item ?: FWVideoShoppingProduct())
    }
    return list
  }

  fun deserialize(responseJson: JSONObject?): FWVideoShoppingProduct? {
    responseJson ?: return null
    val productId = if (responseJson.has(PRODUCT_ID_KEY)) responseJson.optString(PRODUCT_ID_KEY) else null
    val name = if (responseJson.has(NAME_KEY)) responseJson.optString(NAME_KEY) else null
    val description = if (responseJson.has(DESCRIPTION_KEY)) responseJson.optString(DESCRIPTION_KEY) else null
    val units = deserializeUnits(responseJson.optJSONArray(UNITS_KEY))
    val isAvailable = responseJson.optBoolean(IS_AVAILABLE_KEY, true)

    return FWVideoShoppingProduct(
      productId = productId,
      name = name,
      description = description,
      units = units,
      isAvailable = isAvailable,
    )
  }

  private fun deserializeUnits(unitsJsonArray: JSONArray?): List<FWVideoShoppingProduct.FWVideoProductUnit>? {
    unitsJsonArray ?: return null
    val list = mutableListOf<FWVideoShoppingProduct.FWVideoProductUnit>()
    (0 until unitsJsonArray.length()).forEach {
      val value = unitsJsonArray.getJSONObject(it)
      val item = deserializeUnit(value)
      list.add(item ?: FWVideoShoppingProduct.FWVideoProductUnit())
    }
    return list
  }

  private fun deserializeUnit(unitsJsonObject: JSONObject?): FWVideoShoppingProduct.FWVideoProductUnit? {
    unitsJsonObject ?: return null
    val unitId = if (unitsJsonObject.has(UNIT_ID_KEY)) unitsJsonObject.optString(UNIT_ID_KEY) else null
    val name = if (unitsJsonObject.has(NAME_KEY)) unitsJsonObject.optString(NAME_KEY) else null
    val price = deserializePrice(unitsJsonObject.optJSONObject(PRICE_KEY))
    val url = if (unitsJsonObject.has(URL_KEY)) unitsJsonObject.optString(URL_KEY) else null
    val imageUrl = if (unitsJsonObject.has(IMAGE_URL_KEY)) unitsJsonObject.optString(IMAGE_URL_KEY) else null
    val options = deserializeOptions(unitsJsonObject.optJSONArray(OPTIONS_KEY))
    val isAvailable = unitsJsonObject.optBoolean(IS_AVAILABLE_KEY, true)

    return FWVideoShoppingProduct.FWVideoProductUnit(
      unitId = unitId,
      name = name,
      price = price,
      url = url,
      imageUrl = imageUrl,
      options = options,
      isAvailable = isAvailable,
    )

  }

  private fun deserializePrice(priceJsonObject: JSONObject?): FWVideoShoppingProduct.FWVideoProductPrice? {
    priceJsonObject ?: return null
    val amount = if (priceJsonObject.has(AMOUNT_KEY)) priceJsonObject.optDouble(AMOUNT_KEY) else null
    val currencyCode = if (priceJsonObject.has(CURRENCY_CODE_KEY)) priceJsonObject.optString(CURRENCY_CODE_KEY) else null

    return FWVideoShoppingProduct.FWVideoProductPrice(
      amount = amount,
      currencyCode = currencyCode,
    )
  }

  private fun deserializeOptions(optionJSONArray: JSONArray?): List<FWVideoShoppingProduct.FWVideoProductOption>? {
    optionJSONArray ?: return null

    val list = mutableListOf<FWVideoShoppingProduct.FWVideoProductOption>()
    (0 until optionJSONArray.length()).forEach {
      val value = optionJSONArray.getJSONObject(it)
      val item = deserializeOption(value)
      list.add(item ?: FWVideoShoppingProduct.FWVideoProductOption())
    }
    return list
  }

  private fun deserializeOption(optionJsonObject: JSONObject?): FWVideoShoppingProduct.FWVideoProductOption? {
    optionJsonObject ?: return null
    val name = if (optionJsonObject.has(NAME_KEY)) optionJsonObject.optString(NAME_KEY) else null
    val value = if (optionJsonObject.has(VALUE_KEY)) optionJsonObject.optString(VALUE_KEY) else null

    return FWVideoShoppingProduct.FWVideoProductOption(
      name = name,
      value = value,
    )
  }

}
