package com.fireworksdk.bridge.models

import org.json.JSONArray
import org.json.JSONObject

object FWVideoShoppingProductSerializer {

  private const val PRODUCT_ID_KEY = "productId"
  private const val NAME_KEY = "name"
  private const val DESCRIPTION_KEY = "description"
  private const val UNITS_KEY = "units"
  private const val IS_AVAILABLE_KEY = "isAvailable"

  private const val UNIT_ID_KEY = "unitId"
  private const val PRICE_KEY = "price"
  private const val URL_KEY = "url"
  private const val IMAGE_URL_KEY = "imageUrl"
  private const val OPTIONS_KEY = "options"

  private const val AMOUNT_KEY = "amount"
  private const val CURRENCY_CODE_KEY = "currencyCode"

  private const val VALUE_KEY = "value"

  fun serialize(model: FWVideoShoppingProduct?): JSONObject? {
    model ?: return null
    val jsonObject = JSONObject()
    jsonObject.put(PRODUCT_ID_KEY, model.productId)
    jsonObject.put(NAME_KEY, model.name)
    jsonObject.put(DESCRIPTION_KEY, model.description)
    jsonObject.put(UNITS_KEY, serializeUnits(model.units))
    jsonObject.put(IS_AVAILABLE_KEY, model.isAvailable)
    return jsonObject
  }

  private fun serializeUnits(list: List<FWVideoShoppingProduct.FWVideoProductUnit>?): JSONArray?  {
    list ?: return null
    val jsonArray = JSONArray()
    for (item in list) {
      jsonArray.put(serializeUnit(item))
    }
    return jsonArray
  }

  private fun serializeUnit(model: FWVideoShoppingProduct.FWVideoProductUnit?): JSONObject?  {
    model ?: return null
    val jsonObject = JSONObject()
    jsonObject.put(UNIT_ID_KEY, model.unitId)
    jsonObject.put(NAME_KEY, model.name)
    jsonObject.put(PRICE_KEY, serializePrice(model.price))
    jsonObject.put(URL_KEY, model.url)
    jsonObject.put(IMAGE_URL_KEY, model.imageUrl)
    jsonObject.put(OPTIONS_KEY, serializeOptions(model.options))
    jsonObject.put(IS_AVAILABLE_KEY, model.isAvailable)
    return jsonObject
  }

  private fun serializePrice(model: FWVideoShoppingProduct.FWVideoProductPrice?): JSONObject?  {
    model ?: return null
    val jsonObject = JSONObject()
    jsonObject.put(AMOUNT_KEY, model.amount)
    jsonObject.put(CURRENCY_CODE_KEY, model.currencyCode)
    return jsonObject
  }

  private fun serializeOptions(list: List<FWVideoShoppingProduct.FWVideoProductOption>?): JSONArray?  {
    list ?: return null
    val jsonArray = JSONArray()
    for (item in list) {
      jsonArray.put(serializeOption(item))
    }
    return jsonArray
  }

  private fun serializeOption(model: FWVideoShoppingProduct.FWVideoProductOption?): JSONObject?  {
    model ?: return null
    val jsonObject = JSONObject()
    jsonObject.put(NAME_KEY, model.name)
    jsonObject.put(VALUE_KEY, model.value)
    return jsonObject
  }
}