package com.fireworksdk.bridge.utils

import android.graphics.Color

object FWColorUtil {

  /**
   * android system default: argb
   */
  var useRgba: Boolean = false

  /**
   * color:
   * #FF3A86FF, #3A86FF
   * 0xFF3A86FF, 0XFF3A86FF, 0x3A86FF, 0X3A86FF
   */
  fun parseColor(color: String): Int {
    return when {
      color.startsWith("0x") || color.startsWith("0X") -> {
        parseIntColor(color)
      }

      else -> {
        parseHashtagColor(color)
      }
    }
  }

  /**
   * color: #FF3A86FF, #3A86FF
   */
  private fun parseHashtagColor(color: String): Int {

    if (useRgba) {
      when (color.length) {
        9 -> {
          val argbStr = color.substring(0, 1) + color.substring(7, 9) + color.substring(1, 7)
          return Color.parseColor(argbStr)
        }
        else -> {}
      }
    }

    return Color.parseColor(color)
  }

  /**
   * color: 0xFF3A86FF, 0XFF3A86FF, 0x3A86FF, 0X3A86FF
   */
  private fun parseIntColor(color: String): Int {

    if (useRgba) {
      when (color.length) {
        10 -> {
          val argbStr = color.substring(0, 2) + color.substring(8, 10) + color.substring(2, 8)
          return argbStr.toInt()
        }
        else -> {}
      }
    }

    return color.toInt()
  }

}
