//
//  FireworkSdk+CTA.swift
//  fw_flutter_sdk
//
//  Created by Jeff Zheng on 2021/12/21.
//

import FireworkVideo
import Foundation

extension FireworkSDKPlugin: FireworkVideoCTADelegate {
    static var videoDetailsForTappingCTAButton: VideoDetails?

    func handleCustomCTAClick(_ viewController: PlayerViewController, url: URL) -> Bool {
        let callbackId = UUID().uuidString
        playerMap.setObject(viewController, forKey: callbackId as NSString)
        DispatchQueue.main.async { [weak self] in
            var arguments: [String: Any?] = [
                "url": url.absoluteString,
                "callbackId": callbackId
            ]

            if let video = FireworkSDKPlugin.videoDetailsForTappingCTAButton {
                arguments["video"] = video.jsObject
                FireworkSDKPlugin.videoDetailsForTappingCTAButton = nil
            }

            self?.channel?.invokeMethod(
                FWEventName.customCTAClick.rawValue,
                arguments: arguments
            )
        }

        return customCTAClickEnabled
    }

    func pausePlayer(_ callbackId: String) {
        if let playerViewController = playerMap.object(forKey: callbackId as NSString),
           let playerViewController = playerViewController as? PlayerViewController {
            playerViewController.pause()
        }
    }

    func resumePlayer(_ callbackId: String) {
        if let playerViewController = playerMap.object(forKey: callbackId as NSString),
           let playerViewController = playerViewController as? PlayerViewController {
            playerViewController.resume()
        }
    }
}
