import 'dart:async';

import 'models/fw_events.dart';

/// Dispatches events to all listeners.
class FWEventBus {
  static FWEventBus? _instance;
  final StreamController _streamController = StreamController.broadcast();

  static FWEventBus _getInstance() {
    _instance ??= FWEventBus._();
    return _instance!;
  }

  FWEventBus._();

  /// Get global single instance of FWEventBus class.
  factory FWEventBus.getInstance() => _getInstance();

  /// Fires an event.
  void fire(FWEvent event) {
    _streamController.add(event);
  }

  /// Listens for events.
  Stream<FWEvent> on() {
    return _streamController.stream
        .where((event) => event is FWEvent)
        .cast<FWEvent>();
  }
}
