import 'dart:async';

import 'package:flutter/foundation.dart';

import 'live_stream_message_details.dart';

import 'live_stream_event_details.dart';
import 'feed_item_details.dart';
import 'fw_error.dart';
import 'shopping_cta_result.dart';
import 'video_playback_details.dart';

class SDKInitEvent {
  /// If error equals null, it means the initialization is successful.
  FWError? error;

  SDKInitEvent({
    this.error,
  });
}

class PlayerHandler {
  /// Pause The video playback associated with this CTA.
  /// Only supported on iOS
  VoidCallback pause;

  /// Resume The video playback associated with this CTA.
  /// Only supported on iOS
  VoidCallback resume;

  PlayerHandler({
    required this.pause,
    required this.resume,
  });
}

class CustomCTAClickEvent {
  /// Action URL that is associated with this CTA.
  String url;

  /// The video playback pause/resume handler associated with this CTA.
  /// Only supported on iOS
  PlayerHandler? playerHandler;

  /// The video playback details for the event.
  VideoPlaybackDetails video;

  CustomCTAClickEvent({
    required this.url,
    this.playerHandler,
    required this.video,
  });
}

class VideoPlaybackEvent {
  VideoPlaybackEventName eventName;
  VideoPlaybackDetails info;

  VideoPlaybackEvent({
    required this.eventName,
    required this.info,
  });
}

class VideoFeedClickEvent {
  FeedItemDetails info;

  VideoFeedClickEvent({
    required this.info,
  });
}

class ShoppingCTAHandler {
  /// Show the loader of shopping CTA.
  /// Only supported on Android
  Future<void> Function() showLoader;

  /// Complete CTA handling process.
  /// The host app could use this method to stop loading and show feedback message.
  Future<void> Function(ShoppingCTAResult result) complete;

  ShoppingCTAHandler({
    required this.showLoader,
    required this.complete,
  });
}

class ShoppingCTAEvent {
  /// The url for the product unit
  String url;

  /// A unique identifier of the product.
  String productId;

  /// A unique identifier of the product unit.
  String unitId;

  /// The handler associated with this CTA.
  ShoppingCTAHandler? ctaHandler;

  /// The video playback details for the event.
  VideoPlaybackDetails video;

  ShoppingCTAEvent({
    this.url = "",
    this.productId = "",
    this.unitId = "",
    this.ctaHandler,
    required this.video,
  });
}

class UpdateProductDetailsEvent {
  /// A unique identifier list of the products.
  List<String> productIds;

  /// The video playback details for the event.
  VideoPlaybackDetails video;

  UpdateProductDetailsEvent({
    required this.productIds,
    required this.video,
  });
}

class CustomClickLinkButtonEvent {
  /// The url for the product unit
  String url;

  /// A unique identifier of the product.
  String productId;

  /// A unique identifier of the product unit.
  String unitId;

  /// The video playback details for the event.
  /// Only supported on Android.
  VideoPlaybackDetails? video;

  CustomClickLinkButtonEvent({
    this.url = "",
    this.productId = "",
    this.unitId = "",
    this.video,
  });
}

class CustomTapProductCardEvent {
  /// The url for the product unit
  String url;

  /// A unique identifier of the product.
  String productId;

  /// A unique identifier of the product unit.
  String unitId;

  /// The video playback details for the event.
  VideoPlaybackDetails video;

  CustomTapProductCardEvent({
    this.url = "",
    this.productId = "",
    this.unitId = "",
    required this.video,
  });
}

class FWEvent {
  String eventName;
  Map<String, dynamic>? arguments;
  FWEvent({
    required this.eventName,
    this.arguments,
  });
}

class LiveStreamEvent {
  LiveStreamEventName eventName;
  LiveStreamEventDetails info;

  LiveStreamEvent({
    required this.eventName,
    required this.info,
  });
}

class LiveStreamChatEvent {
  LiveStreamChatEventName eventName;
  LiveStreamMessageDetails message;
  LiveStreamEventDetails liveStream;

  LiveStreamChatEvent({
    required this.eventName,
    required this.message,
    required this.liveStream,
  });
}

class CustomClickCartIconEvent {
  /// The video playback details for the event.
  VideoPlaybackDetails video;

  CustomClickCartIconEvent({
    required this.video,
  });
}
