import 'ios_font_info.dart';

class ProductInfoViewConfiguration {
  /// Configuration of shopping CTA button.
  ShoppingCTAButtonConfiguration? ctaButton;

  /// Configuration of link button next to shopping CTA button.
  LinkButtonConfiguration? linkButton;

  /// Configuration of product card
  ProductCardConfiguration? productCard;

  ProductInfoViewConfiguration({
    this.ctaButton,
    this.linkButton,
    this.productCard,
  });

  ProductInfoViewConfiguration deepCopy() => ProductInfoViewConfiguration(
        ctaButton: ctaButton?.deepCopy(),
        linkButton: linkButton?.deepCopy(),
        productCard: productCard?.deepCopy(),
      );
}

enum ShoppingCTAButtonText {
  addToCart,
  shopNow,
}

class ShoppingCTAButtonConfiguration {
  /// The text of shopping CTA button.
  ShoppingCTAButtonText? text;

  /// The background color of CTA button.
  /// Only supported on iOS.
  String? backgroundColor;

  /// The text color of CTA button.
  /// Only supported on iOS.
  String? textColor;

  /// The font size of CTA button.
  /// Only supported on iOS.
  double? fontSize;

  /// The iOS font info of "Add to cart" button.
  /// The property is ignored when fontSize is not set.
  /// Only supported on iOS.
  IOSFontInfo? iOSFontInfo;

  ShoppingCTAButtonConfiguration({
    this.text,
    this.backgroundColor,
    this.textColor,
    this.fontSize,
    this.iOSFontInfo,
  });

  ShoppingCTAButtonConfiguration deepCopy() => ShoppingCTAButtonConfiguration(
        text: text,
        backgroundColor: backgroundColor,
        textColor: textColor,
        fontSize: fontSize,
        iOSFontInfo: iOSFontInfo?.deepCopy(),
      );
}

class LinkButtonConfiguration {
  bool? isHidden;
  LinkButtonConfiguration({
    this.isHidden,
  });

  LinkButtonConfiguration deepCopy() => LinkButtonConfiguration(
        isHidden: isHidden,
      );
}

class ProductCardConfiguration {
  /// The theme of product card.
  ProductCardTheme? theme;

  /// The corner radius of product card.
  double? cornerRadius;

  /// CTA button is hidden or not.
  bool? isCtaButtonHidden;

  /// The text of shopping CTA button.
  ProductCardCTAButtonText? ctaButtonText;

  /// The cta button style of product card.
  /// Only supported on iOS.
  ProductCardCTAButtonStyle? ctaButtonStyle;

  /// The price configuration of product card.
  ProductCardPriceConfiguration? priceConfiguration;

  /// The width of product card.
  /// Only supported on iOS.
  double? width;

  /// The height of product card.
  /// Only supported on iOS.
  double? height;

  /// The background color of product card.
  /// Only supported on iOS.
  String? backgroundColor;

  /// The icon configuration of product card.
  /// Only supported on iOS.
  ProductCardIconConfiguration? iconConfiguration;

  /// The label configuration of product card.
  /// Only supported on iOS.
  ProductCardLabelConfiguration? nameLabel;

  ProductCardConfiguration({
    this.theme,
    this.cornerRadius,
    this.isCtaButtonHidden,
    this.ctaButtonText,
    this.ctaButtonStyle,
    this.priceConfiguration,
    this.width,
    this.height,
    this.backgroundColor,
    this.iconConfiguration,
    this.nameLabel,
  });

  ProductCardConfiguration deepCopy() => ProductCardConfiguration(
        theme: theme,
        cornerRadius: cornerRadius,
        isCtaButtonHidden: isCtaButtonHidden,
        ctaButtonText: ctaButtonText,
        ctaButtonStyle: ctaButtonStyle?.deepCopy(),
        priceConfiguration: priceConfiguration?.deepCopy(),
        width: width,
        height: height,
        backgroundColor: backgroundColor,
        iconConfiguration: iconConfiguration?.deepCopy(),
        nameLabel: nameLabel?.deepCopy(),
      );
}

enum ProductCardTheme {
  light,
  dark,
}

enum ProductCardCTAButtonText {
  shopNow,
  buyNow,
}

class ProductCardCTAButtonStyle {
  /// The text color of CTA button.
  /// Only supported on iOS.
  String? textColor;

  /// The font size of CTA button.
  /// Only supported on iOS.
  double? fontSize;

  /// The iOS font info of "Add to cart" button.
  /// The property is ignored when fontSize is not set.
  /// Only supported on iOS.
  IOSFontInfo? iOSFontInfo;

  ProductCardCTAButtonStyle({
    this.textColor,
    this.fontSize,
    this.iOSFontInfo,
  });

  ProductCardCTAButtonStyle deepCopy() => ProductCardCTAButtonStyle(
        textColor: textColor,
        fontSize: fontSize,
        iOSFontInfo: iOSFontInfo?.deepCopy(),
      );
}

class ProductCardPriceConfiguration {
  @Deprecated('This property is deprecated and has no effect')
  bool? isHidden;

  /// The axis of price label.
  /// Default to 'horizontal'.
  /// Only supported on iOS.
  ProductCardPriceLabelAxis? axis;

  /// The label configuration of price.
  /// Only supported on iOS.
  ProductCardLabelConfiguration? priceLabel;

  /// The label configuration of original price.
  /// Only supported on iOS.
  ProductCardLabelConfiguration? originalPriceLabel;

  /// The default display order is [priceLabel, originalPriceLabel]. When the value is `true`, the order is reversed.
  /// Only supported on iOS.
  bool? isPriceFirst;

  ProductCardPriceConfiguration({
    this.isHidden,
    this.axis,
    this.priceLabel,
    this.originalPriceLabel,
    this.isPriceFirst,
  });

  ProductCardPriceConfiguration deepCopy() => ProductCardPriceConfiguration(
        // ignore: deprecated_member_use_from_same_package
        isHidden: isHidden,
        axis: axis,
        priceLabel: priceLabel?.deepCopy(),
        originalPriceLabel: originalPriceLabel?.deepCopy(),
        isPriceFirst: isPriceFirst,
      );
}

enum ProductCardPriceLabelAxis {
  horizontal,
  vertical,
}

class ProductCardLabelConfiguration {
  /// The text color of label.
  /// Only supported on iOS.
  String? textColor;

  /// The font size of label.
  /// Only supported on iOS.
  double? fontSize;

  /// Number of lines to show.
  /// Only supported on iOS.
  int? numberOfLines;

  /// The iOS font info.
  /// The property is ignored when fontSize is not set.
  /// Only supported on iOS.
  IOSFontInfo? iOSFontInfo;

  ProductCardLabelConfiguration({
    this.textColor,
    this.fontSize,
    this.numberOfLines,
    this.iOSFontInfo,
  });

  ProductCardLabelConfiguration deepCopy() => ProductCardLabelConfiguration(
        textColor: textColor,
        fontSize: fontSize,
        numberOfLines: numberOfLines,
        iOSFontInfo: iOSFontInfo?.deepCopy(),
      );
}

class ProductCardIconConfiguration {
  /// The corner radius of icon.
  /// Only supported on iOS.
  double? cornerRadius;

  ProductCardIconConfiguration({
    this.cornerRadius,
  });

  ProductCardIconConfiguration deepCopy() => ProductCardIconConfiguration(
        cornerRadius: cornerRadius,
      );
}
