import 'ios_font_info.dart';

/// Only supported on iOS.
class VideoPlayerCTAStyle {
  /// The background color of CTA button.
  /// Defaults to #3A86FF.
  String? backgroundColor;

  /// The text color of CTA button.
  /// Defaults to #FFFFFF.
  String? textColor;

  /// The font size of CTA button.
  /// Defaults to 14.
  double? fontSize;

  /// The iOS font info of CTA button.
  /// The property is ignored when fontSize is not set.
  /// Only supported on iOS.
  IOSFontInfo? iOSFontInfo;

  VideoPlayerCTAStyle({
    this.backgroundColor,
    this.textColor,
    this.fontSize,
    this.iOSFontInfo,
  });

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) {
      return true;
    }

    if (other is VideoPlayerCTAStyle) {
      return backgroundColor == other.backgroundColor &&
          textColor == other.textColor &&
          fontSize == other.fontSize &&
          iOSFontInfo == other.iOSFontInfo;
    }

    return false;
  }

  @override
  int get hashCode =>
      backgroundColor.hashCode ^
      textColor.hashCode ^
      fontSize.hashCode ^
      iOSFontInfo.hashCode;

  VideoPlayerCTAStyle deepCopy() => VideoPlayerCTAStyle(
        backgroundColor: backgroundColor,
        textColor: textColor,
        fontSize: fontSize,
        iOSFontInfo: iOSFontInfo?.deepCopy(),
      );
}
