enum VideoPlayerLogoOption {
  disabled,
  creator,
  channelAggregator,
}

class VideoPlayerLogoConfiguration {
  /// Specifies the logo type.
  /// Defaults to 'disabled'.
  /// Only supported on iOS.
  VideoPlayerLogoOption option;

  /// Specifies the logo encoding id.
  /// Required when option is 'creator' or 'channelAggregator'.
  /// Only supported on iOS.
  String? encodedId;

  /// logo is clickable or not, default value is true.
  bool isClickable;

  VideoPlayerLogoConfiguration({
    required this.option,
    this.encodedId,
    this.isClickable = true,
  });

  @override
  bool operator ==(Object other) {
    if (identical(this, other)) {
      return true;
    }

    if (other is VideoPlayerLogoConfiguration) {
      return option == other.option &&
          encodedId == other.encodedId &&
          isClickable == other.isClickable;
    }

    return false;
  }

  @override
  int get hashCode =>
      option.hashCode ^ encodedId.hashCode ^ isClickable.hashCode;

  VideoPlayerLogoConfiguration deepCopy() => VideoPlayerLogoConfiguration(
        option: option,
        encodedId: encodedId,
        isClickable: isClickable,
      );
}
