import '../../models/open_video_player_configuration.dart';
import '../../models/video_player_configuration.dart';
import '../../models/video_player_cta_delay.dart';
import '../../models/video_player_cta_style.dart';
import '../../models/video_player_native_configuration.dart';
import '../../utils/model_utils/replay_badge_configuration_util.dart';
import 'countdown_timer_configuration_util.dart';
import 'ios_font_info_util.dart';
import 'video_player_button_configuration_util.dart';
import 'video_player_logo_configuration_util.dart';

class VideoPlayerConfigurationUtil {
  static Map<String, dynamic> toJson(VideoPlayerConfiguration? config) {
    Map<String, dynamic> json = {};

    if (config == null) {
      return json;
    }

    if (config.playerStyle != null) {
      json["playerStyle"] = config.playerStyle!.name;
    }

    if (config.videoCompleteAction != null) {
      json["videoCompleteAction"] = config.videoCompleteAction!.name;
    }

    if (config.showShareButton != null) {
      json["showShareButton"] = config.showShareButton!;
    }

    if (config.ctaButtonStyle != null) {
      json["ctaButtonStyle"] = _convertCTAStyleToJson(config.ctaButtonStyle!);
    }

    if (config.showPlaybackButton != null) {
      json["showPlaybackButton"] = config.showPlaybackButton!;
    }

    if (config.showMuteButton != null) {
      json["showMuteButton"] = config.showMuteButton!;
    }

    if (config.showBranding != null) {
      json["showBranding"] = config.showBranding!;
    }

    if (config.ctaDelay != null) {
      json["ctaDelay"] = _convertCTADelayToJson(config.ctaDelay!);
    }

    if (config.ctaHighlightDelay != null) {
      json["ctaHighlightDelay"] =
          _convertCTADelayToJson(config.ctaHighlightDelay!);
    }

    if (config.shareBaseURL != null) {
      json["shareBaseURL"] = config.shareBaseURL!;
    }

    if (config.ctaWidth != null) {
      json["ctaWidth"] = config.ctaWidth!.name;
    }

    if (config.buttonConfiguration != null) {
      json["buttonConfiguration"] = VideoPlayerButtonConfigurationUtil.toJson(
          config.buttonConfiguration!);
    }

    if (config.videoPlayerLogoConfiguration != null) {
      json["videoPlayerLogoConfiguration"] =
          VideoPlayerLogoConfigurationUtil.toJson(
              config.videoPlayerLogoConfiguration!);
    }

    if (config.showVideoDetailTitle != null) {
      json["showVideoDetailTitle"] = config.showVideoDetailTitle!;
    }

    if (config.replayBadgeConfiguration != null) {
      json["replayBadgeConfiguration"] =
          ReplayBadgeConfigurationUtil.toJson(config.replayBadgeConfiguration!);
    }

    if (config.countdownTimerConfiguration != null) {
      json["countdownTimerConfiguration"] =
          CountdownTimerConfigurationUtil.toJson(
              config.countdownTimerConfiguration!);
    }

    if (config is OpenVideoPlayerConfiguration) {
      if (config.enablePictureInPicture != null) {
        json["enablePictureInPicture"] = config.enablePictureInPicture!;
      }
    } else if (config is VideoPlayerNativeConfiguration) {
      if (config.enablePictureInPicture != null) {
        json["enablePictureInPicture"] = config.enablePictureInPicture!;
      }
    }

    return json;
  }

  static Map<String, dynamic> _convertCTADelayToJson(
      VideoPlayerCTADelay ctaDelay) {
    Map<String, dynamic> json = {};
    json["type"] = ctaDelay.type.name;
    json["value"] = ctaDelay.value;

    return json;
  }

  static Map<String, dynamic> _convertCTAStyleToJson(
      VideoPlayerCTAStyle ctaStyle) {
    Map<String, dynamic> json = {};
    if (ctaStyle.backgroundColor != null &&
        ctaStyle.backgroundColor!.isNotEmpty) {
      json["backgroundColor"] = ctaStyle.backgroundColor!;
    }

    if (ctaStyle.textColor != null && ctaStyle.textColor!.isNotEmpty) {
      json["textColor"] = ctaStyle.textColor!;
    }

    if (ctaStyle.fontSize != null) {
      json["fontSize"] = ctaStyle.fontSize!.toDouble();
    }

    if (ctaStyle.iOSFontInfo != null) {
      json["iOSFontInfo"] = IOSFontInfoUtil.toJson(ctaStyle.iOSFontInfo!);
    }

    return json;
  }
}
