import 'package:flutter_test/flutter_test.dart';
import 'package:fw_flutter_sdk/src/models/ios_font_info.dart';
import 'package:fw_flutter_sdk/src/models/product_info_view_configuration.dart';
import 'package:fw_flutter_sdk/src/utils/model_utils/product_info_view_configuration_util.dart';

void main() {
  test('ProductInfoViewConfigurationUtil toJson', () {
    final configuration = ProductInfoViewConfiguration(
      ctaButton: ShoppingCTAButtonConfiguration(
        text: ShoppingCTAButtonText.shopNow,
        backgroundColor: "#c0c0c0",
        fontSize: 16,
        textColor: "#000000",
        iOSFontInfo: IOSFontInfo(
          fontName: "Helvetica",
          systemFontStyle: IOSSystemFontStyle.italic,
          systemFontWeight: IOSSystemFontWeight.heavy,
        ),
      ),
      linkButton: LinkButtonConfiguration(isHidden: true),
      productCard: ProductCardConfiguration(
        theme: ProductCardTheme.light,
        cornerRadius: 10,
        isCtaButtonHidden: true,
        ctaButtonText: ProductCardCTAButtonText.buyNow,
        ctaButtonStyle: ProductCardCTAButtonStyle(
          textColor: "#000000",
          fontSize: 16,
          iOSFontInfo: IOSFontInfo(
            fontName: "Helvetica",
            systemFontStyle: IOSSystemFontStyle.italic,
            systemFontWeight: IOSSystemFontWeight.heavy,
          ),
        ),
        priceConfiguration: ProductCardPriceConfiguration(
          isHidden: true,
          axis: ProductCardPriceLabelAxis.horizontal,
          priceLabel: ProductCardLabelConfiguration(
            textColor: "#000000",
            fontSize: 16,
            numberOfLines: 2,
            iOSFontInfo: IOSFontInfo(
              fontName: "Helvetica",
              systemFontStyle: IOSSystemFontStyle.italic,
              systemFontWeight: IOSSystemFontWeight.heavy,
            ),
          ),
          originalPriceLabel: ProductCardLabelConfiguration(
            textColor: "#000000",
            fontSize: 16,
            numberOfLines: 2,
            iOSFontInfo: IOSFontInfo(
              fontName: "Helvetica",
              systemFontStyle: IOSSystemFontStyle.italic,
              systemFontWeight: IOSSystemFontWeight.heavy,
            ),
          ),
          isPriceFirst: true,
        ),
        width: 240,
        height: 150,
        backgroundColor: '#c0c0c0',
        nameLabel: ProductCardLabelConfiguration(
          textColor: "#000000",
          fontSize: 16,
          numberOfLines: 2,
          iOSFontInfo: IOSFontInfo(
            fontName: "Helvetica",
            systemFontStyle: IOSSystemFontStyle.italic,
            systemFontWeight: IOSSystemFontWeight.heavy,
          ),
        ),
        iconConfiguration: ProductCardIconConfiguration(cornerRadius: 10),
      ),
    );

    final json = ProductInfoViewConfigurationUtil.toJson(configuration);
    final ctaButtonJson = json["ctaButton"];
    final linkButtonJson = json["linkButton"];
    final productCardJson = json["productCard"];

    expect(ctaButtonJson is Map<String, dynamic>, true);
    expect(ctaButtonJson["text"], "shopNow");
    expect(ctaButtonJson["backgroundColor"],
        configuration.ctaButton?.backgroundColor);
    expect(ctaButtonJson["fontSize"], configuration.ctaButton?.fontSize);
    expect(ctaButtonJson["textColor"], configuration.ctaButton?.textColor);
    expect(ctaButtonJson["iOSFontInfo"]["fontName"],
        configuration.ctaButton?.iOSFontInfo?.fontName);
    expect(ctaButtonJson["iOSFontInfo"]["systemFontStyle"],
        configuration.ctaButton?.iOSFontInfo?.systemFontStyle?.name);
    expect(ctaButtonJson["iOSFontInfo"]["systemFontWeight"],
        configuration.ctaButton?.iOSFontInfo?.systemFontWeight?.name);
    expect(linkButtonJson is Map<String, dynamic>, true);
    expect(linkButtonJson["isHidden"], configuration.linkButton?.isHidden);

    expect(productCardJson["theme"], configuration.productCard?.theme?.name);
    expect(productCardJson["cornerRadius"],
        configuration.productCard?.cornerRadius);
    expect(productCardJson["isCtaButtonHidden"],
        configuration.productCard?.isCtaButtonHidden);
    expect(productCardJson["ctaButtonText"],
        configuration.productCard?.ctaButtonText?.name);

    expect(productCardJson["ctaButtonStyle"]["textColor"],
        configuration.productCard?.ctaButtonStyle?.textColor);
    expect(productCardJson["ctaButtonStyle"]["fontSize"],
        configuration.productCard?.ctaButtonStyle?.fontSize);
    expect(productCardJson["ctaButtonStyle"]["iOSFontInfo"]["fontName"],
        configuration.productCard?.ctaButtonStyle?.iOSFontInfo?.fontName);
    expect(
        productCardJson["ctaButtonStyle"]["iOSFontInfo"]["systemFontStyle"],
        configuration
            .productCard?.ctaButtonStyle?.iOSFontInfo?.systemFontStyle?.name);
    expect(
        productCardJson["ctaButtonStyle"]["iOSFontInfo"]["systemFontWeight"],
        configuration
            .productCard?.ctaButtonStyle?.iOSFontInfo?.systemFontWeight?.name);

    expect(
        productCardJson["priceConfiguration"]["isHidden"],
        // ignore: deprecated_member_use_from_same_package
        configuration.productCard?.priceConfiguration?.isHidden);
    expect(productCardJson["priceConfiguration"]["axis"],
        configuration.productCard?.priceConfiguration?.axis?.name);
    expect(productCardJson["priceConfiguration"]["isPriceFirst"],
        configuration.productCard?.priceConfiguration?.isPriceFirst);

    final priceLabelJson = productCardJson["priceConfiguration"]["priceLabel"]
        as Map<String, dynamic>;
    expect(priceLabelJson["textColor"],
        configuration.productCard?.priceConfiguration?.priceLabel?.textColor);
    expect(priceLabelJson["fontSize"],
        configuration.productCard?.priceConfiguration?.priceLabel?.fontSize);
    expect(
        priceLabelJson["numberOfLines"],
        configuration
            .productCard?.priceConfiguration?.priceLabel?.numberOfLines);
    expect(
        priceLabelJson["iOSFontInfo"]["fontName"],
        configuration.productCard?.priceConfiguration?.priceLabel?.iOSFontInfo
            ?.fontName);
    expect(
        priceLabelJson["iOSFontInfo"]["systemFontStyle"],
        configuration.productCard?.priceConfiguration?.priceLabel?.iOSFontInfo
            ?.systemFontStyle?.name);
    expect(
        priceLabelJson["iOSFontInfo"]["systemFontWeight"],
        configuration.productCard?.priceConfiguration?.priceLabel?.iOSFontInfo
            ?.systemFontWeight?.name);

    final originalPriceLabelJson = productCardJson["priceConfiguration"]
        ["originalPriceLabel"] as Map<String, dynamic>;
    expect(
        originalPriceLabelJson["textColor"],
        configuration
            .productCard?.priceConfiguration?.originalPriceLabel?.textColor);
    expect(
        originalPriceLabelJson["fontSize"],
        configuration
            .productCard?.priceConfiguration?.originalPriceLabel?.fontSize);
    expect(
        originalPriceLabelJson["numberOfLines"],
        configuration.productCard?.priceConfiguration?.originalPriceLabel
            ?.numberOfLines);
    expect(
        originalPriceLabelJson["iOSFontInfo"]["fontName"],
        configuration.productCard?.priceConfiguration?.originalPriceLabel
            ?.iOSFontInfo?.fontName);
    expect(
        originalPriceLabelJson["iOSFontInfo"]["systemFontStyle"],
        configuration.productCard?.priceConfiguration?.originalPriceLabel
            ?.iOSFontInfo?.systemFontStyle?.name);
    expect(
        originalPriceLabelJson["iOSFontInfo"]["systemFontWeight"],
        configuration.productCard?.priceConfiguration?.originalPriceLabel
            ?.iOSFontInfo?.systemFontWeight?.name);

    expect(productCardJson["width"], configuration.productCard?.width);
    expect(productCardJson["height"], configuration.productCard?.height);
    expect(productCardJson["backgroundColor"],
        configuration.productCard?.backgroundColor);

    final nameLabelJson = productCardJson["nameLabel"] as Map<String, dynamic>;
    expect(nameLabelJson["textColor"],
        configuration.productCard?.nameLabel?.textColor);
    expect(nameLabelJson["fontSize"],
        configuration.productCard?.nameLabel?.fontSize);
    expect(nameLabelJson["numberOfLines"],
        configuration.productCard?.nameLabel?.numberOfLines);
    expect(nameLabelJson["iOSFontInfo"]["fontName"],
        configuration.productCard?.nameLabel?.iOSFontInfo?.fontName);
    expect(
        nameLabelJson["iOSFontInfo"]["systemFontStyle"],
        configuration
            .productCard?.nameLabel?.iOSFontInfo?.systemFontStyle?.name);
    expect(
        nameLabelJson["iOSFontInfo"]["systemFontWeight"],
        configuration
            .productCard?.nameLabel?.iOSFontInfo?.systemFontWeight?.name);
    final iconConfigurationJson =
        productCardJson["iconConfiguration"] as Map<String, dynamic>;
    expect(iconConfigurationJson["cornerRadius"],
        configuration.productCard?.iconConfiguration?.cornerRadius);
  });
}
